@@ -47,6 +47,10 @@ if not os.environ.get('PARSONS_SKIP_IMPORT_ALL'):
     from parsons.pdi.pdi import PDI
     from parsons.azure.azure_blob_storage import AzureBlobStorage
     from parsons.github.github import GitHub
+    from parsons.bloomerang.bloomerang import Bloomerang
+    from parsons.box.box import Box
+    from parsons.sisense.sisense import Sisense
+    from parsons.alchemer.alchemer import SurveyGizmo, Alchemer
 
     __all__ = [
         'VAN',
@@ -88,6 +92,11 @@ if not os.environ.get('PARSONS_SKIP_IMPORT_ALL'):
         'PDI',
         'AzureBlobStorage',
         'GitHub',
+        'Bloomerang',
+        'Box',
+        'Sisense',
+        'SurveyGizmo',
+        'Alchemer'
     ]
 
 # Define the default logging config for Parsons and its submodules. For now the
@@ -103,5 +112,7 @@ logger.addHandler(_handler)
 if os.environ.get('TESTING'):
     # Log less stuff in automated tests
     logger.setLevel('WARNING')
+elif os.environ.get('DEBUG'):
+    logger.setLevel('DEBUG')
 else:
     logger.setLevel('INFO')
