@@ -6,22 +6,22 @@ import logging
 
 logger = logging.getLogger(__name__)
 
+API_URL = 'https://actionnetwork.org/api/v2'
+
 
 class ActionNetwork(object):
     """
     `Args:`
         api_token: str
             The OSDI API token
-        api_url:
-            The end point url
     """
-    def __init__(self, api_token=None, api_url=None):
+    def __init__(self, api_token=None):
         self.api_token = check_env.check('AN_API_TOKEN', api_token)
         self.headers = {
             "Content-Type": "application/json",
             "OSDI-API-Token": self.api_token
         }
-        self.api_url = check_env.check('AN_API_URL', api_url)
+        self.api_url = API_URL
         self.api = APIConnector(self.api_url, headers=self.headers)
 
     def _get_page(self, object_name, page, per_page=25):
@@ -30,7 +30,7 @@ class ActionNetwork(object):
             per_page = 25
             logger.info("Action Network's API will not return more than 25 entries per page. \
             Changing per_page parameter to 25.")
-        page_url = f"{self.api_url}/{object_name}?page={page}&per_page={per_page}"
+        page_url = f"{object_name}?page={page}&per_page={per_page}"
         return self.api.get_request(url=page_url)
 
     def _get_entry_list(self, object_name, limit=None, per_page=25):
@@ -75,11 +75,10 @@ class ActionNetwork(object):
             A  JSON of the entry. If the entry doesn't exist, Action Network returns
             ``{'error': 'Couldn't find person with id = <id>'}``.
         """
-        return self.api.get_request(url=f"{self.api_url}/people/{person_id}")
+        return self.api.get_request(url=f"people/{person_id}")
 
-    def add_person(self, email_address, given_name=None, family_name=None, tags=[],
-                   languages_spoken=[], postal_addresses=[],
-                   **kwargs):
+    def add_person(self, email_address, given_name=None, family_name=None, tags=None,
+                   languages_spoken=None, postal_addresses=None, **kwargs):
         """
         `Args:`
             email_address:
@@ -126,14 +125,19 @@ class ActionNetwork(object):
         data = {
             "person": {
                 "email_addresses": email_addresses_field,
-                "given_name": given_name,
-                "family_name": family_name,
-                "languages_spoken": languages_spoken,
-                "postal_addresses": postal_addresses,
-                "custom_fields": {**kwargs}
               },
-            "add_tags": tags
         }
+        if given_name is not None:
+            data["person"]["given_name"] = given_name
+        if family_name is not None:
+            data["person"]["family_name"] = family_name
+        if languages_spoken is not None:
+            data["person"]["languages_spoken"] = languages_spoken
+        if postal_addresses is not None:
+            data["person"]["postal_address"] = postal_addresses
+        if tags is not None:
+            data["add_tags"] = tags
+        data["person"]["custom_fields"] = {**kwargs}
         response = self.api.post_request(url=f"{self.api_url}/people", data=json.dumps(data))
         identifiers = response['identifiers']
         person_id = [entry_id.split(':')[1]
@@ -209,7 +213,7 @@ class ActionNetwork(object):
             A  JSON of the entry. If the entry doesn't exist, Action Network returns
             "{'error': 'Couldn't find tag with id = <id>'}"
         """
-        return self.api.get_request(url=f"{self.api_url}/tags/{tag_id}")
+        return self.api.get_request(url=f"tags/{tag_id}")
 
     def add_tag(self, name):
         """
@@ -227,3 +231,51 @@ class ActionNetwork(object):
                      for entry_id in identifiers if 'action_network:' in entry_id][0]
         logger.info(f"Tag {person_id} successfully added to tags.")
         return response
+
+    def create_event(self, title, start_date=None, location=None):
+        """
+        Create an event in Action Network
+
+        `Args:`
+            title: str
+                The public title of the event
+            start_date: str OR datetime
+                OPTIONAL: The starting date & time. If a string, use format "YYYY-MM-DD HH:MM:SS"
+                (hint: the default format you get when you use `str()` on a datetime)
+            location: dict
+                OPTIONAL: A dict of location details. Can include any combination of the types of
+                values in the following example:
+                .. code-block:: python
+
+                    my_location = {
+                        "venue": "White House",
+                        "address_lines": [
+                            "1600 Pennsylvania Ave"
+                        ],
+                        "locality": "Washington",
+                        "region": "DC",
+                        "postal_code": "20009",
+                        "country": "US"
+                    }
+
+        `Returns:`
+            Dict of Action Network Event data.
+        """
+
+        data = {
+            "title": title
+        }
+
+        if start_date:
+            start_date = str(start_date)
+            data["start_date"] = start_date
+
+        if isinstance(location, dict):
+            data["location"] = location
+
+        event_dict = self.api.post_request(url=f"{self.api_url}/events", data=json.dumps(data))
+
+        an_event_id = event_dict["_links"]["self"]["href"].split('/')[-1]
+        event_dict["event_id"] = an_event_id
+
+        return event_dict
