@@ -346,7 +346,7 @@ class RedshiftTableUtilities(object):
         """
         Gets the column names (and some other column info) for a table.
 
-        If you just need the column names, you can treat the return value like a list, eg:
+        If you just need the column names, run ``get_columns_list()`` as it is faster.
 
         .. code-block:: python
 
@@ -361,8 +361,17 @@ class RedshiftTableUtilities(object):
         `Returns:`
             A dict mapping column name to a dict with extra info. The keys of the dict are ordered
             just like the columns in the table. The extra info is a dict with format
-            ``{'data_type': str, 'max_length': int or None, 'max_precision': int or None,
-               'max_scale': int or None, 'is_nullable': bool}``
+
+            .. code-block:: python
+
+                {
+                'data_type': str,
+                'max_length': int or None,
+                'max_precision': int or None,
+                'max_scale': int or None,
+                'is_nullable': bool
+                }
+
         """
 
         query = f"""
@@ -390,6 +399,23 @@ class RedshiftTableUtilities(object):
             for row in self.query(query)
         }
 
+    def get_columns_list(self, schema, table_name):
+        """
+        Gets the just the column names for a table.
+
+        `Args:`
+            schema: str
+                The schema name
+            table_name: str
+                The table name
+        `Returns:`
+            A list of column names.
+        """
+
+        first_row = self.query(f"select * from {schema}.{table_name} limit 1")
+
+        return first_row.columns
+
     def get_views(self, schema=None, view=None):
         """
         List views.
